==> zio-aws-mediatailor_3-5.17.103.1-sources.jar: zio/aws/mediatailor/model/DeletePlaybackConfigurationRequest.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DeletePlaybackConfigurationRequest(name: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.DeletePlaybackConfigurationRequest = {
    import DeletePlaybackConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.DeletePlaybackConfigurationRequest
      .builder()
      .name(__string.unwrap(name): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.mediatailor.model.DeletePlaybackConfigurationRequest.ReadOnly =
    zio.aws.mediatailor.model.DeletePlaybackConfigurationRequest
      .wrap(buildAwsValue())
}
object DeletePlaybackConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.DeletePlaybackConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.mediatailor.model.DeletePlaybackConfigurationRequest =
      zio.aws.mediatailor.model.DeletePlaybackConfigurationRequest(name)
    def name: __string
    def getName: ZIO[Any, Nothing, __string] = ZIO.succeed(name)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.DeletePlaybackConfigurationRequest
  ) extends zio.aws.mediatailor.model.DeletePlaybackConfigurationRequest.ReadOnly {
    override val name: __string =
      zio.aws.mediatailor.model.primitives.__string(impl.name())
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.DeletePlaybackConfigurationRequest
  ): zio.aws.mediatailor.model.DeletePlaybackConfigurationRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-mediatailor_3-5.17.178.1-sources.jar: zio/aws/mediatailor/model/DeletePlaybackConfigurationRequest.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DeletePlaybackConfigurationRequest(name: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.DeletePlaybackConfigurationRequest = {
    import DeletePlaybackConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.DeletePlaybackConfigurationRequest
      .builder()
      .name(name: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.mediatailor.model.DeletePlaybackConfigurationRequest.ReadOnly =
    zio.aws.mediatailor.model.DeletePlaybackConfigurationRequest
      .wrap(buildAwsValue())
}
object DeletePlaybackConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.DeletePlaybackConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.mediatailor.model.DeletePlaybackConfigurationRequest =
      zio.aws.mediatailor.model.DeletePlaybackConfigurationRequest(name)
    def name: __string
    def getName: ZIO[Any, Nothing, __string] = ZIO.succeed(name)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.DeletePlaybackConfigurationRequest
  ) extends zio.aws.mediatailor.model.DeletePlaybackConfigurationRequest.ReadOnly {
    override val name: __string = impl.name(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.DeletePlaybackConfigurationRequest
  ): zio.aws.mediatailor.model.DeletePlaybackConfigurationRequest.ReadOnly =
    new Wrapper(impl)
}
